# OpenAcquisition
[![License: MIT](https://img.shields.io/github/license/DennisGoldfarb/OpenAcquisition)](https://opensource.org/licenses/MIT)
[![Documentation Status](https://readthedocs.org/projects/openacquisition/badge/?version=main)](https://openacquisition.readthedocs.io/en/main/?badge=main)
![Build](https://github.com/DennisGoldfarb/OpenAcquisition/actions/workflows/ci-cd.yml/badge.svg)
[![codecov](https://codecov.io/gh/DennisGoldfarb/OpenAcquisition/branch/main/graph/badge.svg?token=CIMEPT9GCZ)](https://codecov.io/gh/DennisGoldfarb/OpenAcquisition)
[![Version](https://img.shields.io/pypi/v/openacquisition)](https://pypi.org/project/openacquisition/)


Python library to create data acquisition algorithms for mass spectrometers

## Requirements

## Installation

```bash
$ pip install openacquisition
```

## Usage

## Contributing
Interested in contributing? Check out the contributing guidelines. 
Please note that this project is released with a Code of Conduct. 
By contributing to this project, you agree to abide by its terms.

## License
`OpenAcquisition` was created by the [Goldfarb Lab](https://sites.wustl.edu/goldfarblab) at Washington University School of Medicine in St. Louis. It is licensed under the terms of the MIT license.
